@@ -24,11 +24,14 @@ use Encode 'from_to';
 
 our @EXPORT = qw(init do_request run_tests run_test);
 
-use Benchmark::Timer;
-my $timer = Benchmark::Timer->new();
+my $timer;
+eval {
+    require Benchmark::Timer;
+    $timer = Benchmark::Timer->new();
+};
 my $SavedCapture;
 
-our $server = $ENV{'OPENAPI_TEST_SERVER'} ||
+our $server = $ENV{'OPENRESTY_TEST_SERVER'} ||
     $OpenResty::Config{'test_suite.server'} or
     die "No server specified.\n";
 our ($user, $password, $host);
@@ -128,18 +131,20 @@ END {
     use Hash::Merge 'merge';
     #use Data::Dumper;
     #warn scalar $timer->reports;
-    my $file = "t/cur-timer.dat";
-    my $cur_data = $timer->data;
-    if (!$cur_data) {
-        return;
+    if ($timer) {
+        my $file = "t/cur-timer.dat";
+        my $cur_data = $timer->data;
+        if (!$cur_data) {
+            return;
+        }
+        $cur_data = { @$cur_data };
+        #warn Dumper($cur_data);
+        if (-f $file) {
+            my $last_data = LoadFile($file);
+            $cur_data = merge($cur_data, $last_data);
+        }
+        DumpFile($file, $cur_data);
     }
-    $cur_data = { @$cur_data };
-    #warn Dumper($cur_data);
-    if (-f $file) {
-        my $last_data = LoadFile($file);
-        $cur_data = merge($cur_data, $last_data);
-    }
-    DumpFile($file, $cur_data);
 }
 
 1;
